
------------------------------------------------------
--	BEGIN Prevent skipped releases
------------------------------------------------------

	USE [ECMPS_AUX]
	GO
	DECLARE @LAST_RELEASE_DATE DATETIME = '03/09/2022',
			@LAST_VERSION VARCHAR(25) = '2022 Q1',
			@DB_AT_RELEASE_DATE DATETIME,
			@DB_AT_VERSION VARCHAR(25)
		
	SELECT @DB_AT_VERSION=REVISION, @DB_AT_RELEASE_DATE=RELEASE_DATE 
	FROM ECMPS_AUX.dbo.ECMPS_VERSION_LOG 
	WHERE IS_CURRENT_FLG ='Y'

	IF(DATEDIFF(dd, @DB_AT_RELEASE_DATE, @LAST_RELEASE_DATE) <> 0 OR @DB_AT_VERSION<>@LAST_VERSION)
	BEGIN
		PRINT 'UPDATE FAILED: You are not at the correct release to apply this update.' + CHAR(13)
			+ 'This upgrade is for Version ' + @LAST_VERSION + ', dated ' + CONVERT(VARCHAR(10), @LAST_RELEASE_DATE, 101) +'.' + CHAR(13)
			+ 'Your database is at Version ' + @DB_AT_VERSION +', dated ' + CONVERT(VARCHAR(10), @DB_AT_RELEASE_DATE, 101)+ '.' + CHAR(13) + 
			'Please visit http://ecmps.camdsupport.com/downloads_shared_update.shtml to get previous update(s).'

		SET NOEXEC ON
	END

------------------------------------------------------
--	END Prevent skipped releases
------------------------------------------------------


PRINT 'Clean up the workspace tables'
-- Clean up the workspace tables
EXECUTE ECMPS_WS.Client.TruncateWorkspaceTables NULL, NULL
GO 


------------------------------------------------------
--	ECMPS STRUCTURE SQL (BEGIN)
------------------------------------------------------

USE ECMPS
GO 

------------------------------------------------------
--	ECMPS STRUCTURE SQL (END)
------------------------------------------------------


------------------------------------------------------
--	ECMPS_WS STRUCTURE SQL (BEGIN)
------------------------------------------------------

USE ECMPS_WS
GO 

------------------------------------------------------
--	ECMPS_WS STRUCTURE SQL (END)
------------------------------------------------------


------------------------------------------------------
--	ECMPS_AUX STRUCTURE SQL (BEGIN)
------------------------------------------------------

USE ECMPS_AUX
GO 

------------------------------------------------------
--	ECMPS_AUX STRUCTURE SQL (END)
------------------------------------------------------


------------------------------------------------------
--	ECMPS DATA SQL (BEGIN)
------------------------------------------------------

USE ECMPS
GO

------------------------------------------------------
--	ECMPS DATA SQL (END)
------------------------------------------------------


------------------------------------------------------
--	ECMPS_AUX DATA SQL (BEGIN)
------------------------------------------------------

USE ECMPS_AUX
GO

SET NUMERIC_ROUNDABORT OFF
GO
SET ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS, NOCOUNT ON
GO
SET DATEFORMAT YMD
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION

PRINT(N'Update row in [dbo].[SYSTEM_PARAMETER]')
UPDATE [dbo].[SYSTEM_PARAMETER] SET [PARAM_VALUE3]=N'CAMD at AskCAMD@epa.gov' WHERE [SYS_PARAM_ID] = 4 AND (sys_param_id not in (1, 2, 5))

PRINT(N'Update row in [dbo].[RESPONSE_CATALOG]')
UPDATE [dbo].[RESPONSE_CATALOG] SET [RESPONSE_CATALOG_DESCRIPTION]='You reported a TestResultCode of "INPROG" indicating that the baseline data collection period is still in progress, but the EndDate of the associated fuel flow-to-load baseline data is prior to the test quarter.' WHERE [RESPONSE_CATALOG_ID] = 41971

PRINT(N'Update rows in [dbo].[CHECK_CATALOG]')
UPDATE [dbo].[CHECK_CATALOG] SET [TECH_NOTE]='{\rtf1\ansi\ansicpg1252\deff0\deflang1033{\fonttbl{\f0\fnil Times New Roman;}{\f1\fnil\fcharset0 Times New Roman;}}
\viewkind4\uc1\pard\f0\fs20 For the fuel flow-to-load test with a valid Reporting Period\f1 ,\f0\par
\par
\pard\li675 Locate the latest QA Supp Data record for the location where the TestTypeCode is equal to "FF2LBAS", the MonitoringSystemID is equal to the MonitoringSystemID in the current test, the EndDate is on or prior to the last day of the quarter of the current test, and CAN_SUBMIT is equal to "N".\par
\par
Locate the latest Fuel Flow-to-Load Baseline Data record for the system where the EndDate is on or prior to the last day of the quarter of the current test.\par
\par
\f1 If TestResultCode is not equal to "INPROG",\f0\par
\par
\pard\li1350 If there is no QA Supp Data record \ul and\ulnone  there is no Fuel Flow-to-Load Baseline Data record,\par
\pard\li2025 return result A.\par
\pard\li1350\par
Otherwise,\par
\pard\li675\par
\pard\li2025 If no Fuel Flow-to-Load Baseline Data record was found, or the TestSummaryID of both records are equal, or the EndDate of the QA Supp Data record is later than the EndDate of the Fuel Flow-to-Load Baseline Data record,\par
\pard\li1350\par
\pard\li2700 Locate a QA Supp Attribute record for the QA Supp Data record where the Attribute_Name is equal to "TEST_BASIS_CD".\par
\pard\li2025\par
\pard\li2700 If found,\par
\pard\li2025\par
\pard\li3375 If the TestBasisCode in the current test is equal to "Q" and the Attribute_Value in the retrieved QA Supp Attribute record is equal to "H"; or the TestBasisCode in the current test is equal to "H" and the Attribute_Value in the retrieved QA Supp Attribute record is equal to "Q",\par
\pard\li4050 return result B.\par
\pard\li3375\par
\pard\li2025 Otherwise,\par
\pard\li2700 If the TestBasisCode in the current test is equal to "Q" and the BaselineFuelFlowToLoadRatio in the retrieved Fuel Flow-to-Load Baseline Data record is null, or the TestBasisCode in the current test is equal to "H" and the BaselineGHR is the retrieved Fuel Flow-to-Load Baseline Data is null,\par
\pard\li3375 return result B.\par
\pard\li675\f1 Otherwise,\par
\pard\li1350\f0\par
If \f1 a\f0  QA Supp Data record \ul\f1 or\ulnone\f0  \f1 a\f0  Fuel Flow-to-Load Baseline Data record\f1  was located above,\f0\par
\pard\li675\par
\pard\li2025 If no Fuel Flow-to-Load Baseline Data record was found, or the TestSummaryID of both records are equal, or the EndDate of the QA Supp Data record is later than the EndDate of the Fuel Flow-to-Load Baseline Data record,\par
\pard\li675\f1\par
\pard\li2700 Set BaselineEndDate to the EndDate in the QA Supp Data record.\par
\par
\pard\li2025 Otherwise,\f0\par
\pard\li2700\f1\par
Set BaselineEndDate to the EndDate in the Fuel Flow-to-Load Baseline Data record.\par
\par
\pard\li2025 If the BaselineEndDate is prior to the first day of the quarter of the fuel flow-to-load test,\par
\par
\pard\li2700 Locate all System Component records for the system where the ComponentTypeCode is equal to "GFFM" or "OFFM", and the EndDate is null or is on or after the Baseline End Date.\par
\par
\f0 Locate \f1 a\f0  QA Supp Data record for the location where the TestTypeCode is equal to "FF\f1 ACC\f0 "\f1  or "FFACCTT"\f0 , the \f1 ComponentID is equal to any of the ComponentIDs in the System Component records retrieved above\f0 , \f1 and \f0 the EndDate\f1  or ReinstallationDate\f0  is on or \f1 after the BaselineEndDate.\f0\par
\f1\par
If none are found,\par
\pard\li3375 return result C.\f0\par
\pard\li1350\par
\par
\pard\li2025\f1\par
\pard\li2700\f0\par
\f1\par
\par
\pard\li675\par
\pard\li2025\par
\pard\li2700\f0\par
\f1\par
\par
}
' WHERE [CHECK_CATALOG_ID] = 1132
UPDATE [dbo].[CHECK_CATALOG] SET [TECH_NOTE]='{\rtf1\ansi\ansicpg1252\deff0\deflang1033{\fonttbl{\f0\fnil\fcharset0 Times New Roman;}{\f1\fnil Times New Roman;}}
\viewkind4\uc1\pard\f0\fs20 Set \b\i FF2LAccuracyBeginYearQuarter\b0\i0  = null.\par
Set \b\i FF2LAccuracyEndYearQuarter\b0\i0  = null.\par
Set \b\i FF2LProblemTestNumList\b0\i0  = null.\par
Set \b\i FF2LProblemQuarterList\b0\i0  = null.\par
\par
\par
if (\b\i FF2LAccuracyEligible\b0\i0  == true)\par
\par
\pard\li675\f1 Locate \f0 any \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where the \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID\f1  and the TestResult is equal to \f0 "FAILED"\f1  and the \f0 quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0  and the quarter is subsequent to the quarter of the later of the \b\i PriorAccuracyRecord\b0\i0 .EndDate and the \b\i PriorAccuracyRecord\b0\i0 .ReinstallationDate.\par
\par
if (\b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is found)\par
\par
\pard\li1350 Set \b\i FF2LProblemTestnumList\b0\i0  =\b\i  FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0 .TestNumber\par
Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Fuel Flow to Load Test Failed".\par
exit check.\par
\par
\pard\li675\f1 Locate \f0 any \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where the \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID\f1  and the TestResult is \f0 NULL \f1 and the \f0 quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0  and the quarter is subsequent to the quarter of the later of the \b\i PriorAccuracyRecord\b0\i0 .EndDate and the \b\i PriorAccuracyRecord\b0\i0 .ReinstallationDate.\par
\pard\li1350\par
\pard\li675 if (\b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is found)\par
\pard\li1350\par
Set \b\i FF2LProblemTestnumList\b0\i0  =\b\i  FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0 .TestNumber\par
Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Fuel Flow to Load Test Has Critical Errors".\par
exit check.\par
\pard\li2025\par
\pard\li675\f1 Locate \f0 any \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where the \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID\f1  and the\f0  QANeedsEvaluation flag \f1 is \f0 equal to "Y" \f1 and the \f0 quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0  and the quarter is subsequent to the quarter of the later of the \b\i PriorAccuracyRecord\b0\i0 .EndDate and the \b\i PriorAccuracyRecord\b0\i0 .ReinstallationDate.\par
\pard\li2025\par
\pard\li675 if (\b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is found)\par
\par
\pard\li1350 Set \b\i FF2LProblemTestnumList\b0\i0  =\b\i  FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0 .TestNumber\par
Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "Fuel Flow to Load Test Has Not Yet Been Evaluated".\par
exit check.\par
\pard\li675\tab\par
\par
Set \b\i FF2LAccuracyBeginYearQuarter\b0\i0  = the quarter after the quarter of the \b\i FF2LAccuracyCheckDate.\b0\i0\par
Set \b\i FF2LAccuracyEndYearQuarter\b0\i0  = \f1 the \f0 quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0 .\par
\par
\par
Set \i PriorAccuracyDateHour\i0  = \b\i FF2LAccuracyCheckDate\b0\i0 .\par
Set \i TestOrSystemQuarter\i0  = the quarter of the later of \i PriorAccuracyDate\i0  and \b\i CurrentFuelFlowRecord\b0\i0 .SystemBeginDate .\par
Set \i CurrentOperatingQuarter\i0  = the quarter of the \b\i CurrentOperatingDateHour\b0\i0 .\par
\par
\par
if   ( \i CurrentOperatingQuarter\i0  is after the quarter subsequent to the \i TestOrSystemQuarter\i0  )\par
\par
\pard\li1350 Locate the earliest \i FF2LBaselineDataRecord\i0  in \b\i FF2LBaseline\f1 RecordsByLocationForQAStatus\b0\i0\f0  where:\par
\par
\pard\li2025 1) System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) EndDateHour is after the \i PriorAccuracyDateHour\i0 .\par
3) EndDateHour is before the earlier of the \b\i CurrentOperatingDateHour\b0\i0 , AND the 5th quarter after the \i TestOrSystemQuarter\i0 .\par
\pard\li1350\par
\par
if  ( \i FF2LBaselineDataRecord\i0  is found )\par
\par
\pard\li2025 if   ( \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter is before the \i CurrentOperatingQuarter\i0  )\par
\par
\pard\li2700 Set \i MissingQuarterList\i0  = "".\par
Set \i BadResultQuarterList\i0  = "".\par
Set \i BadResultTestList\i0  = "".\par
\par
for each \i TargetQuarter\i0  from the quarter subsequent to the \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter to the quarter before the \i CurrentOperatingQuarter\i0 .\par
\pard\li3375\f1\par
Locate a \b\i\f0 Location\f1 ReportingFrequency\b0\i0  record for \f0 the test location\f1  where\f0 :\par
\par
\pard\li4050 1)\f1  ReportingFrequencyCode = "\f0 OS\f1 ",\par
\f0 2) \f1 Begin\f0 Quarter\f1  is on or before \i\f0 TargetQuarter\i0  \f1 ,\par
\f0 3)\f1  End\f0 Quarter\f1  is null or is on or afte\f0 r \i TargetQuarter\i0  \f1 .\par
\pard\li3375\par
\f0 If  ( NOT found )  OR  ( \i TargetQuarter\i0  is 2nd or 3rd quarter )\par
\pard\li4050\par
Locate \i SystemOperatingSuppDataRecord\i0  in \b\i SystemOperatingSuppDataRecordsByLocation\b0\i0  where:\par
\par
\pard\li4725 1) SystemId is equal to \b\i FuelFlowComponentRecordToCheck\b0\i0 .SystemId.\par
2) OpSuppDataTypeCode is equal to "OP".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li4050\par
if  ( \i SystemOperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li4725 Set \i OpHourCount\i0  = \i SystemOperatingSuppDataRecord\i0 .Hours.\par
\pard\li4050\par
else\f1\par
\par
\pard\li4725 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li5400 1) FuelCode is equal to \b\i\f1 CurrentFuelFlowRecord.\b0\i0 FuelCode\f0 .\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li4725\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li5400 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li4725\par
else\par
\par
\pard\li5400\f1 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li6075 1) FuelCode is null.\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li5400\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )  AND  ( \i OperatingSuppDataRecord\i0 .OpValue is equal to 0 )\par
\par
\pard\li6075 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li5400\par
else\par
\par
\pard\li6075 Set \i OpHourCount\i0  = null.\par
\pard\li4050\par
\par
\f1 Locate \f0 a \i FF2LTestRecord \i0\f1 in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f0 :\par
\par
\pard\li4725 1)\f1  \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) \f1 TestResult\f0 Code\f1  is \f0 equal to "PASSED", "EXC168H" or "FEW168H".\par
3) CalendarYear/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li4050\par
if  ( \i FF2LTestRecord \i0  is NOT found )\par
\par
\pard\li4725 if  ( ( \i OpHourCount\i0  is null )  OR  ( \i OpHourCount\i0  is greater than 0 ) )  AND  ( \i TargetQuarter is NOT equal to TestOrSystemQuarter\i0  )\par
\pard\li5400 Append \i TargetQuarter\i0  to \i MissingQuarterList\i0 .\par
\pard\li4050\par
else\par
\pard\li4725\par
if  ( \i OpHourCount\i0  is NOT null )\par
\par
\pard\li5400 if  ( \i FF2LTestRecord\i0 .\f1 TestResult\f0 Code\f1  \f0 is equal to "PASSED" or "EXC168H" ) AND ( \i OpHourCount\i0  is less than 168 )\par
\par
\pard\li6075 Append \i TargetQuarter\i0  to \i BadResultQuarterList\i0 .\par
Append \i FF2LTestRecord\i0 .\f1 Test\f0 Number\f1  \f0 to \i BadResultTestList\i0 .\par
\pard\li4725\par
\pard\li5400 else if  ( \i FF2LTestRecord\i0 .\f1 TestResult\f0 Code\f1  \f0 is equal to "FEW168H" ) AND ( \i OpHourCount\i0  is greater than or equal to 168 )\par
\par
\pard\li6075 Append \i TargetQuarter\i0  to \i BadResultQuarterList\i0 .\par
Append \i FF2LTestRecord\i0 .\f1 Test\f0 Number\f1  \f0 to \i BadResultTestList\i0 .\par
\pard\li3375\par
\par
\pard\li2700 if  ( \i MissingQuarterList\i0  NOT equal to "" )\par
\par
\pard\li3375 Set \b\i FF2LProblemQuarterList\b0\i0  = \i MissingQuarterList\i0 .\par
Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Missing Fuel Flow to Load Test".\par
\pard\li2700\par
else if ( \i BadResultQuarterList\i0  NOT equal to "" )\par
\par
\pard\li3375 Set \b\i FF2LProblemQuarterList\b0\i0  = \i BadResultQuarterList\i0 .\par
Set \b\i FF2LProblemTestNumList\b0\i0  = \i BadResultTestList\i0 .\par
Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Invalid Fuel Flow to Load Test Result".\par
\pard\li2700\par
else\par
\pard\li3375 if  ( \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter is after the \i TestOrSystemQuarter\i0  )\par
\par
\pard\li4050 Set \b\i FF2LProblemQuarterList\b0\i0  = "".\par
\par
for each \i TargetQuarter \i0 from the quarter subsequent to the \i TestOrSystemQuarter\i0  AND through the \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter.\par
\pard\li4725\f1\par
Locate a \b\i\f0 Location\f1 ReportingFrequency\b0\i0  record for \f0 the test location\f1  where\f0 :\par
\par
\pard\li5400 1)\f1  ReportingFrequencyCode = "\f0 OS\f1 ",\par
\f0 2) \f1 Begin\f0 Quarter\f1  is on or before \i\f0 TargetQuarter\i0  \f1 ,\par
\f0 3)\f1  End\f0 Quarter\f1  is null or is on or afte\f0 r \i TargetQuarter\i0  \f1 .\par
\pard\li4725\par
\f0 If  ( NOT found )  OR  ( \i TargetQuarter\i0  is 2nd or 3rd quarter )\par
\f1\par
\pard\li5400 Locate \f0 a \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f0 :\par
\par
\pard\li6075 1)\f1  \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) \f1 TestResult\f0 Code\f1  is \f0 equal to "INPROG".\par
3) CalendarYear/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li5400\par
if  ( \b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is NOT found )\par
\par
\pard\li6075 Locate \i SystemOperatingSuppDataRecord\i0  in \b\i SystemOperatingSuppDataRecordsByLocation\b0\i0  where:\par
\par
\pard\li6750 1) SystemId is equal to \b\i FuelFlowComponentRecordToCheck\b0\i0 .SystemId.\par
2) OpSuppDataTypeCode is equal to "OP".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li6075\par
if  ( \i SystemOperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li6750 Set \i OpHourCount\i0  = \i SystemOperatingSuppDataRecord\i0 .Hours.\par
\pard\li6075\par
else\f1\par
\par
\pard\li6750 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li7425 1) FuelCode is equal to \b\i\f1 CurrentFuelFlowRecord.\b0\i0 FuelCode\f0 .\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li6750\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li7425 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li6750\par
else\par
\par
\pard\li7425\f1 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li8100 1) FuelCode is null.\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li7425\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )  AND  ( \i OperatingSuppDataRecord\i0 .OpValue is equal to 0 )\par
\par
\pard\li8100 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li7425\par
else\par
\par
\pard\li8100 Set \i OpHourCount\i0  = null.\par
\pard\li6075\par
if  ( ( \i OpHourCount\i0  is null )  AND  ( \i TargetQuarter \i0 is on or after the quarter of \b\i CurrentFuelFlowRecord\b0\i0 .SystemBeginDate ) )  OR   ( ( \i OpHourCount\i0  is NOT null )  AND  ( \i OpHourCount\i0  is greater than 0 ) )\par
\pard\li6750 Append \i TargetQuarter\i0  to \b\i FF2LProblemQuarterList\b0\i0 .\par
\pard\li4050\par
if  ( \b\i FF2LProblemQuarterList\b0\i0  is NOT equal to "" )\par
\par
\pard\li4725 Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Inprogress Fuel Flow to Load Test Required".\par
\pard\li1350\par
else\par
\par
\pard\li2025 if  ( \b\i CurrentOperatingQuarter\b0\i0  is before the 5th quarter after the \i TestOrSystemQuarter\i0  )\par
\pard\li2700\par
Set \b\i FF2LProblemQuarterList\b0\i0  = "".\par
\par
for each \i TargetQuarter \i0 from the quarter subsequent to the \i TestOrSystemQuarter\i0  AND before the \i CurrentOperatingQuarter\i0 .\par
\pard\li3375\f1\par
Locate a \b\i\f0 Location\f1 ReportingFrequency\b0\i0  record for \f0 the test location\f1  where\f0 :\par
\par
\pard\li4050 1)\f1  ReportingFrequencyCode = "\f0 OS\f1 ",\par
\f0 2) \f1 Begin\f0 Quarter\f1  is on or before \i\f0 TargetQuarter\i0  \f1 ,\par
\f0 3)\f1  End\f0 Quarter\f1  is null or is on or afte\f0 r \i TargetQuarter\i0  \f1 .\par
\pard\li3375\par
\f0 If  ( NOT found )  OR  ( \i TargetQuarter\i0  is 2nd or 3rd quarter )\par
\f1\par
\pard\li4050 Locate \f0 a \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f0 :\par
\par
\pard\li4725 1)\f1  \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) \f1 TestResult\f0 Code\f1  is \f0 equal to "INPROG".\par
3) CalendarYear/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li4050\par
if  ( \b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is NOT found )\par
\par
\pard\li4725 Locate \i SystemOperatingSuppDataRecord\i0  in \b\i SystemOperatingSuppDataRecordsByLocation\b0\i0  where:\par
\par
\pard\li5400 1) SystemId is equal to \b\i FuelFlowComponentRecordToCheck\b0\i0 .SystemId.\par
2) OpSuppDataTypeCode is equal to "OP".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li4725\par
if  ( \i SystemOperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li5400 Set \i OpHourCount\i0  = \i SystemOperatingSuppDataRecord\i0 .Hours.\par
\pard\li4725\par
else\f1\par
\par
\pard\li5400 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li6075 1) FuelCode is equal to \b\i\f1 CurrentFuelFlowRecord.\b0\i0 FuelCode\f0 .\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li5400\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li6075 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li5400\par
else\par
\par
\pard\li6075\f1 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li6750 1) FuelCode is null.\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li6075\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )  AND  ( \i OperatingSuppDataRecord\i0 .OpValue is equal to 0 )\par
\par
\pard\li6750 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li6075\par
else\par
\par
\pard\li6750 Set \i OpHourCount\i0  = null.\par
\pard\li4725\par
if  ( ( \i OpHourCount\i0  is null )  AND  ( \i TargetQuarter \i0 is on or after the quarter of \b\i CurrentFuelFlowRecord\b0\i0 .SystemBeginDate ) )  OR   ( ( \i OpHourCount\i0  is NOT null )  AND  ( \i OpHourCount\i0  is greater than 0 ) )\par
\pard\li5400 Append \i TargetQuarter\i0  to \b\i FF2LProblemQuarterList\b0\i0 .\par
\pard\li2700\par
if  ( \b\i FF2LProblemQuarterList\b0\i0  is NOT equal to "" )\par
\par
\pard\li3375 Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Inprogress Fuel Flow to Load Test Required".\par
\pard\li2025\par
else\par
\pard\li2700 Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Baseline Period Expired".\par
\pard\par
}
' WHERE [CHECK_CATALOG_ID] = 2287
UPDATE [dbo].[CHECK_CATALOG] SET [TECH_NOTE]='{\rtf1\ansi\ansicpg1252\deff0\deflang1033{\fonttbl{\f0\fnil\fcharset0 Times New Roman;}{\f1\fnil Times New Roman;}}
\viewkind4\uc1\pard\f0\fs20 Set \b\i FF2LPEIBeginYearQuarter\b0\i0  = null.\par
Set \b\i FF2LPEIEndYearQuarter\b0\i0  = null.\par
Set \b\i FF2LProblemTestnumList\b0\i0  = null.\par
Set \b\i FF2LProblemQuarterList\b0\i0  = null.\par
\par
\par
if (\b\i FF2LPEIEligible\b0\i0  == true)\par
\par
\pard\li675\f1 Locate \f0 any \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where the \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID\f1  and the TestResult\f0 Code\f1  is equal to \f0 "FAILED"\f1  and the \f0 Year/Quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0  and the Year/Quarter is subsequent to the quarter of the \b\i PriorPEIRecord\b0\i0 .EndDate.\par
\par
if (\b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is found)\par
\pard\f1\par
\pard\li1350 Locate \f0 a \f1 record in \b\i QACertificationEventRecords\b0\i0  \f0 WHERE\f1\par
\pard\li675\par
\pard\li1350\f0 a) \f1 the \f0 Component\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0\f1 .\f0 Component\f1 ID \f0 AND\par
b) the QACertEventCode is equal to "410"\par
c) the RequiredTestCode is equal to "53"AND\par
d) the \f1 QACertEventDate/Hour is after the EndDate/Hour\f0  and of the located failed \b\i FF2L\f1 TestRecordsByLocationForQAStatu\f0 s\b0\i0  record.\f1\par
\f0 e) \f1 the QACertEventDate\f0 /Hour\f1  \f0 is \f1 prior to the \b\i\f0 CurrentOperatingDate/Hour \b0\i0\f1\par
\pard\li675\par
\pard\li1350 if (\b\i QACertificationEventRecords\b0\i0  is\f0  not\f1  found)\par
\pard\li675\f0\par
\pard\li2025 Set \b\i FF2LProblemTestnumList\b0\i0  =\b\i  FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0 .TestNumber\par
Set \b\i CurrentPEI\f1 Status\b0\i0  \f0  = "OOC-Fuel Flow to Load Test Failed".\par
Return result \b\i CurrentPEI\f1 Status\b0\i0\f0 .\par
\pard\li1350\par
\pard\li675\f1 Locate \f0 any \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where the \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID\f1  and the TestResult\f0 Code\f1  is \f0 NULL \f1 and the \f0 Year/Quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0  and the Year/Quarter is subsequent to the quarter of the \b\i PriorPEIRecord\b0\i0 .EndDate.\par
\pard\li1350\par
\pard\li675 if (\b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is found)\par
\par
\pard\li1350 Set \b\i FF2LProblemTestnumList\b0\i0  =\b\i  FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0 .TestNumber\par
Set \b\i CurrentPEI\f1 Status\b0\i0  \f0  = "OOC-Fuel Flow to Load Test Has Critical Errors".\par
Return result \b\i CurrentPEI\f1 Status\b0\i0\f0 .\par
\par
\pard\li675\f1 Locate \f0 any \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where the \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID\f1  and the\f0  QANeedsEvaluation flag \f1 is \f0 equal to "Y" \f1 and the \f0 Year/Quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0  and the Year/Quarter is subsequent to the quarter of the \b\i PriorPEIRecord\b0\i0 .EndDate.\par
\pard\li2025\par
\pard\li675 if (\b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is found)\par
\par
\pard\li1350 Set \b\i FF2LProblemTestnumList\b0\i0  =\b\i  FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0 .TestNumber\par
Set \b\i CurrentPEI\f1 Status\b0\i0  \f0  = "Fuel Flow to Load Test Has Not Yet Been Evaluated".\par
Return result \b\i CurrentPEI\f1 Status\b0\i0\f0 .\par
\pard\li675\par
\par
Set \b\i FF2LPEIBeginYearQuarter\b0\i0  to the quarter after the quarter of the \b\i FF2LPEICheckDate\b0\i0 .\par
Set \b\i FF2LPEIEndYearQuarter\b0\i0  = \f1 the \f0 quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0 .\par
\par
\par
Set \i CurrentOperatingQuarter\i0  = the quarter of the \b\i CurrentOperatingDateHour\b0\i0 .\par
\par
\par
if   ( \i CurrentOperatingQuarter\i0  is after the quarter subsequent to the \b\i PriorPEIRecord\b0\i0 .EndDateHour )\par
\par
\pard\li1350 Locate the earliest \i FF2LBaselineDataRecord\i0  in \b\i FF2LBaseline\f1 RecordsByLocationForQAStatus\b0\i0\f0  where:\par
\par
\pard\li2025 1) System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) EndDateHour is after the \b\i PriorPEIRecord\b0\i0 .EndDateHour.\par
3) EndDateHour is before the earlier of the \b\i CurrentOperatingDateHour\b0\i0 , AND the 5th quarter after the \b\i PriorPEIRecord\b0\i0 .EndDateHour.\par
\pard\li1350\par
\par
if  ( \i FF2LBaselineDataRecord\i0  is found )\par
\par
\pard\li2025 if  ( \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter is before the \i CurrentOperatingQuarter\i0  )\par
\par
\pard\li2700 Set \i MissingQuarterList\i0  = "".\par
Set \i BadResultQuarterList\i0  = "".\par
Set \i BadResultTestList\i0  = "".\par
\par
for each \i TargetQuarter\i0  from the quarter subsequent to the \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter to the quarter before the \i CurrentOperatingQuarter\i0 .\par
\pard\li3375\f1\par
Locate a \b\i\f0 Location\f1 ReportingFrequency\b0\i0  record for \f0 the test location\f1  where\f0 :\par
\par
\pard\li4050 1)\f1  ReportingFrequencyCode = "\f0 OS\f1 ",\par
\f0 2) \f1 Begin\f0 Quarter\f1  is on or before \i\f0 TargetQuarter\i0  \f1 ,\par
\f0 3)\f1  End\f0 Quarter\f1  is null or is on or afte\f0 r \i TargetQuarter\i0  \f1 .\par
\pard\li3375\par
\f0 If  ( NOT found )  OR  ( \i TargetQuarter\i0  is 2nd or 3rd quarter )\par
\par
\pard\li4050 Locate \i SystemOperatingSuppDataRecord\i0  in \b\i SystemOperatingSuppDataRecordsByLocation\b0\i0  where:\par
\par
\pard\li4725 1) SystemId is equal to \b\i FuelFlowComponentRecordToCheck\b0\i0 .SystemId.\par
2) OpSuppDataTypeCode is equal to "OP".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li4050\par
if  ( \i SystemOperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li4725 Set \i OpHourCount\i0  = \i SystemOperatingSuppDataRecord\i0 .Hours.\par
\pard\li4050\par
else\f1\par
\par
\pard\li4725 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li5400 1) FuelCode is equal to \b\i\f1 CurrentFuelFlowRecord.\b0\i0 FuelCode\f0 .\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li4725\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li5400 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li4725\par
else\par
\par
\pard\li5400\f1 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li6075 1) FuelCode is null.\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li5400\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )  AND  ( \i OperatingSuppDataRecord\i0 .OpValue is equal to 0 )\par
\par
\pard\li6075 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li5400\par
else\par
\par
\pard\li6075 Set \i OpHourCount\i0  = null.\par
\pard\li4050\par
\par
\f1 Locate \f0 a \i FF2LTestRecord \i0\f1 in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f0 :\par
\par
\pard\li4725 1)\f1  \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) \f1 TestResult\f0 Code\f1  is \f0 equal to "PASSED", "EXC168H" or "FEW168H".\par
3) CalendarYear/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li4050\par
if  ( \i FF2LTestRecord \i0  is NOT found )\par
\par
\pard\li4725 if  ( ( \i OpHourCount\i0  is null )  OR  ( \i OpHourCount\i0  is greater than 0 ) )  AND  ( \i TargetQuarter is NOT equal to \i0 quarter of the \b\i PriorPEIRecord\b0\i0 .EndDateHour )\par
\pard\li5400 Append \i TargetQuarter\i0  to \i MissingQuarterList\i0 .\par
\pard\li4050\par
else\par
\pard\li4725\par
if  ( \i OpHourCount\i0  is NOT null )\par
\par
\pard\li5400 if  ( \i FF2LTestRecord\i0 .\f1 TestResult\f0 Code\f1  \f0 is equal to "PASSED" or "EXC168H" ) AND ( \i OpHourCount\i0  is less than 168 )\par
\par
\pard\li6075 Append \i TargetQuarter\i0  to \i BadResultQuarterList\i0 .\par
Append \i FF2LTestRecord\i0 .\f1 Test\f0 Number\f1  \f0 to \i BadResultTestList\i0 .\par
\pard\li4725\par
\pard\li5400 else if  ( \i FF2LTestRecord\i0 .\f1 TestResult\f0 Code\f1  \f0 is equal to "FEW168H" ) AND ( \i OpHourCount\i0  is greater than or equal to 168 )\par
\par
\pard\li6075 Append \i TargetQuarter\i0  to \i BadResultQuarterList\i0 .\par
Append \i FF2LTestRecord\i0 .\f1 Test\f0 Number\f1  \f0 to \i BadResultTestList\i0 .\par
\pard\li2700\par
\par
if  ( \i MissingQuarterList\i0  NOT equal to "" )\par
\par
\pard\li3375 Set \b\i FF2LProblemQuarterList\b0\i0  = \i MissingQuarterList\i0 .\par
Set \b\i CurrentPEI\f1 Status\b0\i0\f0  = "OOC-Missing Fuel Flow to Load Test".\par
\pard\li2700\par
else if ( \i BadResultQuarterList\i0  NOT equal to "" )\par
\par
\pard\li3375 Set \b\i FF2LProblemQuarterList\b0\i0  = \i BadResultQuarterList\i0 .\par
Set \b\i FF2LProblemTestnumList\b0\i0  = \i BadResultTestList\i0 .\par
Set \b\i CurrentPEI\f1 Status\b0\i0\f0  = "OOC-Invalid Fuel Flow to Load Test Result".\par
\pard\li2700\par
else\par
\pard\li3375 if  ( \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter is after the quarter of the \b\i PriorPEIRecord\b0\i0 .EndDateHour )\par
\par
\pard\li4050 Set \b\i FF2LProblemQuarterList\b0\i0  = "".\par
\par
for each \i TargetQuarter \i0 from the quarter subsequent to the \b\i PriorPEIRecord\b0\i0 .EndDateHour AND through the \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter.\par
\pard\li4725\f1\par
Locate a \b\i\f0 Location\f1 ReportingFrequency\b0\i0  record for \f0 the test location\f1  where\f0 :\par
\par
\pard\li5400 1)\f1  ReportingFrequencyCode = "\f0 OS\f1 ",\par
\f0 2) \f1 Begin\f0 Quarter\f1  is on or before \i\f0 TargetQuarter\i0  \f1 ,\par
\f0 3)\f1  End\f0 Quarter\f1  is null or is on or afte\f0 r \i TargetQuarter\i0  \f1 .\par
\pard\li4725\par
\f0 If  ( NOT found )  OR  ( \i TargetQuarter\i0  is 2nd or 3rd quarter )\par
\f1\par
\pard\li5400 Locate \f0 a \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f0 :\par
\par
\pard\li6075 1)\f1  \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) \f1 TestResult\f0 Code\f1  is \f0 equal to "INPROG".\par
3) CalendarYear/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li5400\par
if  ( \b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is NOT found )\par
\par
\pard\li6075 Locate \i SystemOperatingSuppDataRecord\i0  in \b\i SystemOperatingSuppDataRecordsByLocation\b0\i0  where:\par
\par
\pard\li6750 1) SystemId is equal to \b\i FuelFlowComponentRecordToCheck\b0\i0 .SystemId.\par
2) OpSuppDataTypeCode is equal to "OP".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li6075\par
if  ( \i SystemOperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li6750 Set \i OpHourCount\i0  = \i SystemOperatingSuppDataRecord\i0 .Hours.\par
\pard\li6075\par
else\f1\par
\par
\pard\li6750 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li7425 1) FuelCode is equal to \b\i\f1 CurrentFuelFlowRecord.\b0\i0 FuelCode\f0 .\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li6750\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li7425 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li6750\par
else\par
\par
\pard\li7425\f1 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li8100 1) FuelCode is null.\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li7425\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )  AND  ( \i OperatingSuppDataRecord\i0 .OpValue is equal to 0 )\par
\par
\pard\li8100 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li7425\par
else\par
\par
\pard\li8100 Set \i OpHourCount\i0  = null.\par
\pard\li6075\par
if  ( ( \i OpHourCount\i0  is null )  AND  ( \i TargetQuarter \i0 is on or after the quarter of \b\i CurrentFuelFlowRecord\b0\i0 .SystemBeginDate ) )  OR   ( ( \i OpHourCount\i0  is NOT null )  AND  ( \i OpHourCount\i0  is greater than 0 ) )\par
\pard\li6750\par
Append \i TargetQuarter\i0  to \b\i FF2LProblemQuarterList\b0\i0 .\par
\pard\li4050\par
if  ( \b\i FF2LProblemQuarterList\b0\i0  is NOT equal to "" )\par
\par
\pard\li4725 Set \b\i CurrentPEI\f1 Status\b0\i0\f0  = "OOC-Inprogress Fuel Flow to Load Test Required".\par
\pard\li1350\par
else\par
\par
\pard\li2025 if  ( \b\i CurrentOperatingQuarter\b0\i0  is before the 5th quarter after the \b\i PriorPEIRecord\b0\i0 .EndDateHour )\par
\par
\pard\li2700 Set \b\i FF2LProblemQuarterList\b0\i0  = "".\par
\par
for each \i TargetQuarter \i0 from the quarter subsequent to the \b\i PriorPEIRecord\b0\i0 .EndDateHour AND before the \i CurrentOperatingQuarter\i0 .\par
\pard\li3375\f1\par
Locate a \b\i\f0 Location\f1 ReportingFrequency\b0\i0  record for \f0 the test location\f1  where\f0 :\par
\par
\pard\li4050 1)\f1  ReportingFrequencyCode = "\f0 OS\f1 ",\par
\f0 2) \f1 Begin\f0 Quarter\f1  is on or before \i\f0 TargetQuarter\i0  \f1 ,\par
\f0 3)\f1  End\f0 Quarter\f1  is null or is on or afte\f0 r \i TargetQuarter\i0  \f1 .\par
\pard\li3375\par
\f0 If  ( NOT found )  OR  ( \i TargetQuarter\i0  is 2nd or 3rd quarter )\par
\f1\par
\pard\li4050 Locate \f0 a \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f0 :\par
\par
\pard\li4725 1)\f1  \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) \f1 TestResult\f0 Code\f1  is \f0 equal to "INPROG".\par
3) CalendarYear/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li4050\par
if  ( \b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is NOT found )\par
\par
\pard\li4725 Locate \i SystemOperatingSuppDataRecord\i0  in \b\i SystemOperatingSuppDataRecordsByLocation\b0\i0  where:\par
\par
\pard\li5400 1) SystemId is equal to \b\i FuelFlowComponentRecordToCheck\b0\i0 .SystemId.\par
2) OpSuppDataTypeCode is equal to "OP".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li4725\par
if  ( \i SystemOperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li5400 Set \i OpHourCount\i0  = \i SystemOperatingSuppDataRecord\i0 .Hours.\par
\pard\li4725\par
else\f1\par
\par
\pard\li5400 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li6075 1) FuelCode is equal to \b\i\f1 CurrentFuelFlowRecord.\b0\i0 FuelCode\f0 .\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li5400\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li6075 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li5400\par
else\par
\par
\pard\li6075\f1 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li6750 1) FuelCode is null.\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li6075\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )  AND  ( \i OperatingSuppDataRecord\i0 .OpValue is equal to 0 )\par
\par
\pard\li6750 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li6075\par
else\par
\par
\pard\li6750 Set \i OpHourCount\i0  = null.\par
\pard\li4725\par
if  ( ( \i OpHourCount\i0  is null )  AND  ( \i TargetQuarter \i0 is on or after the quarter of \b\i CurrentFuelFlowRecord\b0\i0 .SystemBeginDate ) )  OR   ( ( \i OpHourCount\i0  is NOT null )  AND  ( \i OpHourCount\i0  is greater than 0 ) )\par
\par
\pard\li5400 Append \i TargetQuarter\i0  to \b\i FF2LProblemQuarterList\b0\i0 .\par
\pard\li3375\par
\pard\li2700 if  ( \b\i FF2LProblemQuarterList\b0\i0  is NOT equal to "" )\par
\par
\pard\li3375 Set \b\i CurrentPEI\f1 Status\b0\i0\f0  = "OOC-Inprogress Fuel Flow to Load Test Required".\par
\pard\li2025\par
else\par
\pard\li2700 Set \b\i CurrentPEI\f1 Status\b0\i0\f0  = "OOC-Baseline Period Expired".\par
\pard\par
}
' WHERE [CHECK_CATALOG_ID] = 2294
UPDATE [dbo].[CHECK_CATALOG] SET [TECH_NOTE]='{\rtf1\ansi\ansicpg1252\deff0\deflang1033{\fonttbl{\f0\fnil Times New Roman;}{\f1\fnil\fcharset0 Times New Roman;}}
\viewkind4\uc1\pard\f0\fs20 Set \b\i Alternate\f1 DailyCal\f0 Record \b0\i0 = null\f1 .\f0\par
\par
if (\b\i Current\f1 DailyCal\f0 Status\b0\i0  begins with "OOC")\par
\par
\pard\li675 if (\b\i Invalid\f1 DailyCal\f0 Record \b0\i0 is not null)\par
\par
\pard\li1350 Set \b\i Current\f1 DailyCal\f0 Status\b0\i0  = \b\i Current\f1 DailyCal\f0 Status\b0\i0  & "*".\par
\par
\pard\li675 Return result \b\i Current\f1 DailyCal\f0 Status\b0\i0 .\par
\par
\pard else if (\b\i DualRangeStatus\b0\i0  = true and \b\i Current\f1 DailyCal\f0 Status\b0\i0  begins with "IC")\par
\par
\pard\li675 if (\b\i CurrentAnalyzerRangeUsed\b0\i0  = "H")\par
\par
\pard\li1350 Set \i AlternateAnalyzerRange\i0  = "L".\par
Set \i AlternateComponentID\i0  = \b\i LowRangeComponentID\b0\i0 .\par
\par
\pard\li675 else\par
\par
\pard\li1350 Set \i AlternateAnalyzerRange\i0  = "H".\par
Set \i AlternateComponentID\i0  = \b\i HighRangeComponentID\b0\i0 .\par
\par
\pard\li675 Locate the \f1 most recent \f0 record in \b\i\f1 DailyCal\f0 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f1 :\par
\par
a)\f0  ComponentID is equal to the \i AlternateComponentID\i0  \f1 AND\par
b)\f0  \f1 ValidFlag = "Y" AND\f0\par
\f1 c) \f0 SpanScaleCode is equal to the \i AlternateAnalyzerRange\i0  \par
\par
if (\b\i\f1 DailyCal\f0 TestRecordsByLocationForQAStatus\b0\i0  is found)\par
\par
\pard\li1350 Set \b\i Alternate\f1 DailyCal\f0 Record \b0\i0 = the found record in \b\i\f1 DailyCal\f0 TestRecordsByLocationForQAStatus\b0\i0 .\par
\pard\li675\par
if (\b\i Alternate\f1 DailyCal\f0 Record \b0\i0 is \f1 not null\f0 )\par
\par
\pard\li1350 if (\b\i Alternate\f1 DailyCal\f0 Record\b0\i0 .TestResultCode = null)\par
\par
\pard\li2025 Set \b\i Current\f1 DailyCal\f0 Status\b0\i0  = "OOC-\f1 Alternate Range \f0 Test Has Critical Errors".\par
\pard\li1350\par
else if (\b\i Alternate\f1 DailyCal\f0 Record\f1 .\b0\i0\f0 TestResultCode = "FAILED")\par
\par
\pard\li2025 Set \b\i Current\f1 DailyCal\f0 Status\b0\i0  = "OOC-\f1 Alternate Range \f0 Test Failed".\par
\pard\li1350\par
else if (\b\i Alternate\f1 DailyCal\f0 Record\b0\i0 .TestResultCode = "ABORTED")\par
\par
\pard\li2025 Set \b\i Current\f1 DailyCal\f0 Status\b0\i0  = "OOC-\f1 Alternate Range \f0 Test Aborted".\par
\par
\pard\li1350\f1 else\par
\par
\pard\li2025\f0 Locate the \f1 latest \f0 record in \b\i\f1 DailyCal\f0 TestRecordsByLocationForQAStatus \b0\i0 for the location\f1  that is\f0  \f1 in or before the \b\i CurrentOperatingDateHour\b0\i0\f0  where\f1 :\par
\par
a)\f0  ComponentID is equal to the \i AlternateComponentID\i0  \f1 AND\par
b) t\f0 he SpanScaleCode is equal to the \i AlternateAnalyzerRange\i0  \par
\f1 c) the TestResultCode is equal to "FAILED" or "ABORTED"\par
\par
if (\b\i DailyCal\f0 TestRecordsByLocationForQAStatus \f1  \b0\i0 is found AND (either \f0 the\f1  \b\i PriorDailyCalRecord\b0\i0  is null or\f0  EndDate/Hour\f1 /Minute\f0  is \f1 after the \b\i PriorDailyCal\f0 Record\b0\i0\f1 .EndDate/Hour/Minute))\par
\par
\pard\li2700\f0 Set \b\i Current\f1 DailyCal\f0 Status\b0\i0  = "OOC-\f1 No Passing \f0 Test A\f1 fter Alternate Range Failed Test\f0 ".\par
\f1 (Report this status in the Evaluation Report under the \b\i PriorDailyCal\f0 Record\b0\i0\f1 .TestDate/Hour.) \f0\par
\pard\li3375\f1\par
\pard\li2025 else if  ( the time ranges between ZeroInjectionDate/Hour/Minute and UpscaleInjectionDate/Hour/Minute for the found test and \b\i PriorDailyCalRecord\b0\i0  overlap )\par
\par
\pard\li2700\f0 Set \b\i Current\f1 DailyCal\f0 Status\b0\i0  = "OOC-Passed Alternate Range Test Overlaps Failed Current Range Test".\par
\f1 (Report this status in the Evaluation Report under the \b\i PriorDailyCal\f0 Record\b0\i0\f1 .TestDate/Hour.) \f0\par
\pard\li2025\par
\f1 else\par
\par
\pard\li2700\f0 Locate the \f1 latest \f0 record in \b\i\f1 DailyCal\f0 TestRecordsByLocationForQAStatus \b0\i0 for the location \f1 that is\f0  \f1 in or before the \b\i CurrentOperatingDateHour\b0\i0\f0  where\f1 :\par
\par
a)\f0  ComponentID is equal to the \b\i ApplicableComponentID\b0\i0\f1  AND\par
b) t\f0 he SpanScaleCode is equal to the \b\i CurrentAnalyzerRangeUsed\b0\i0  \par
\f1 c) the TestResultCode is equal to "FAILED" or "ABORTED"\par
\par
if  ( \b\i DailyCal\f0 TestRecordsByLocationForQAStatus \f1  \b0\i0 is found )\par
\par
\pard\li3375 if ( \f0 EndDate/Hour\f1 /Minute\f0  is \f1 after the \b\i\f0 Alternate\f1 DailyCal\f0 Record\b0\i0\f1 .EndDate/Hour/Minute )\par
\par
\pard\li4050\f0 Set \b\i Current\f1 DailyCal\f0 Status\b0\i0  = "OOC-No Passing Alternate Range Test After Failed Test".\par
\f1 (Report this status in the Evaluation Report under the \b\i PriorDailyCal\f0 Record\b0\i0\f1 .TestDate/Hour.) \f0\par
\pard\li3375\f1\par
else if  ( the time ranges between ZeroInjectionDate/Hour/Minute and UpscaleInjectionDate/Hour/Minute for the found test and \b\i\f0 Alternate\f1 DailyCal\f0 Record\b0\i0\f1  overlap )\par
\par
\pard\li4050\f0 Set \b\i Current\f1 DailyCal\f0 Status\b0\i0  = "OOC-Passed Alternate Range Test Overlaps Failed Current Range Test".\par
\f1 (Report this status in the Evaluation Report under the \b\i PriorDailyCal\f0 Record\b0\i0\f1 .TestDate/Hour.) \f0\par
\pard\li2025\par
\pard\li1350 if (\b\i Current\f1 DailyCal\f0 Status\b0\i0  begins with "OOC"\f1 )\par
\par
\pard\li2025 if (\b\i\f0 Invalid\f1 DailyCal\f0 Record \b0\i0 is not nul\f1 l\f0 )\par
\pard\li1350\par
\pard\li2700 Set \b\i Current\f1 DailyCal\f0 Status\b0\i0  = \b\i Current\f1 DailyCal\f0 Status\b0\i0  & "*".\par
\par
\pard\li2025\f1 else\par
\par
\pard\li2700\f0 Locate the \f1 most recent \f0 record in \b\i\f1 DailyCal\f0 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f1 :\par
\par
a)\f0  ComponentID is equal to the \i AlternateComponentID\i0  \f1 AND\par
b)\f0  \f1 ValidFlag\f0  is equal t\f1 o "N" AND\f0\par
\f1 c) t\f0 he SpanScaleCode is equal to the \i AlternateAnalyzerRange\i0  \f1\par
\par
if (\b\i DailyCal\f0 TestRecordsByLocationForQAStatus \f1  \b0\i0 is found AND \f0 the EndDate/Hour is \f1 after the \b\i\f0 Alternate\f1 DailyCal\f0 Record\b0\i0\f1 .EndDate/Hour)\par
\par
\pard\li3375 Set \b\i\f0 Invalid\f1 DailyCal\f0 Record \b0\i0\f1 = the found record in \b\i DailyCal\f0 TestRecordsByLocationForQAStatus\f1 .\par
\b0\i0\f0 Set \b\i Current\f1 DailyCal\f0 Status\b0\i0  = \b\i Current\f1 DailyCal\f0 Status\b0\i0  & "*".\par
\pard\li675\par
\pard\li2025 Return result \b\i Current\f1 DailyCal\f0 Status\b0\i0  .\par
\par
\pard\f1 elsei\f0 f (\b\i Current\f1 DailyCal\f0 Status\b0\i0  does not begin with "IC")\par
\pard\li1350\par
\pard\li675 Return result \b\i Current\f1 DailyCal\f0 Status\b0\i0  .\f1\par
}
' WHERE [CHECK_CATALOG_ID] = 2325
PRINT(N'Operation applied to 4 rows out of 4')

PRINT(N'Add rows to [dbo].[RESPONSE_CATALOG]')
SET IDENTITY_INSERT [dbo].[RESPONSE_CATALOG] ON
IF NOT EXISTS( SELECT 1 FROM [dbo].[RESPONSE_CATALOG] WHERE [RESPONSE_CATALOG_ID] = 42459)
	INSERT INTO [dbo].[RESPONSE_CATALOG] ([RESPONSE_CATALOG_ID], [RESPONSE_CATALOG_DESCRIPTION], [RESPONSE_TYPE_CD], [RESPONSE_CATALOG_HEADER], [SEVERITY_CD]) VALUES (42459, 'The prior daily calibration test for [compkey] was completed on [date].  However the prior passed alternative range [altscale] test overlaps a previous failed or aborted current range [curscale] test.  When a daily calibration test is failed for a dual-range analyzer, you must complete a passing daily calibration test, after the failed test ends, on both ranges before the monitor is considered to be in-control.', 'CHECK', NULL, NULL)
IF NOT EXISTS( SELECT 1 FROM [dbo].[RESPONSE_CATALOG] WHERE [RESPONSE_CATALOG_ID] = 42460)
	INSERT INTO [dbo].[RESPONSE_CATALOG] ([RESPONSE_CATALOG_ID], [RESPONSE_CATALOG_DESCRIPTION], [RESPONSE_TYPE_CD], [RESPONSE_CATALOG_HEADER], [SEVERITY_CD]) VALUES (42460, 'The prior daily calibration test for [compkey] was completed on [date].  However the prior passed alternative range [altscale] test overlaps a previous failed or aborted current range [curscale] test.  When a daily calibration test is failed for a dual-range analyzer, you must complete a passing daily calibration test, after the failed test ends, on both ranges before the monitor is considered to be in-control.  An invalid daily calibration test completed on [invdate] was ignored.', 'CHECK', NULL, NULL)
IF NOT EXISTS( SELECT 1 FROM [dbo].[RESPONSE_CATALOG] WHERE [RESPONSE_CATALOG_ID] = 42461)
	INSERT INTO [dbo].[RESPONSE_CATALOG] ([RESPONSE_CATALOG_ID], [RESPONSE_CATALOG_DESCRIPTION], [RESPONSE_TYPE_CD], [RESPONSE_CATALOG_HEADER], [SEVERITY_CD]) VALUES (42461, 'The prior daily calibration test for [compkey] was completed on [date] but overlaps with a failed or aborted alternative range [altscale] test.  When a daily calibration test is failed for a dual-range analyzer, you must complete a passing daily calibration test, after the failed test ends, on both ranges before the monitor is considered to be in-control.', 'CHECK', NULL, NULL)
IF NOT EXISTS( SELECT 1 FROM [dbo].[RESPONSE_CATALOG] WHERE [RESPONSE_CATALOG_ID] = 42462)
	INSERT INTO [dbo].[RESPONSE_CATALOG] ([RESPONSE_CATALOG_ID], [RESPONSE_CATALOG_DESCRIPTION], [RESPONSE_TYPE_CD], [RESPONSE_CATALOG_HEADER], [SEVERITY_CD]) VALUES (42462, 'The prior daily calibration test for [compkey] was completed on [date] but overlaps with a failed or aborted alternative range [altscale] test.  When a daily calibration test is failed for a dual-range analyzer, you must complete a passing daily calibration test, after the failed test ends, on both ranges before the monitor is considered to be in-control.  An invalid daily calibration test completed on [invdate] was ignored.', 'CHECK', NULL, NULL)
SET IDENTITY_INSERT [dbo].[RESPONSE_CATALOG] OFF
PRINT(N'Operation applied to 4 rows out of 4')

PRINT(N'Add row to [dbo].[CHECK_CATALOG_PLUGIN]')
SET IDENTITY_INSERT [dbo].[CHECK_CATALOG_PLUGIN] ON
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_PLUGIN] WHERE [CHECK_CATALOG_PLUGIN_ID] = 6387)
	INSERT INTO [dbo].[CHECK_CATALOG_PLUGIN] ([CHECK_CATALOG_PLUGIN_ID], [PLUGIN_NAME], [CHECK_CATALOG_ID], [PLUGIN_TYPE_CD], [CHECK_PARAM_ID], [FIELD_NAME]) VALUES (6387, 'CURSCALE', 2325, 'VALUE', 2724, NULL)
SET IDENTITY_INSERT [dbo].[CHECK_CATALOG_PLUGIN] OFF

PRINT(N'Add rows to [dbo].[CHECK_CATALOG_RESULT]')
SET IDENTITY_INSERT [dbo].[CHECK_CATALOG_RESULT] ON
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7089)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7089, 2325, 'OOC-Passed Alternate Range Test Overlaps Failed Current Range Test', 'CRIT1', 42459, 1)
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7090)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7090, 2325, 'OOC-Passed Alternate Range Test Overlaps Failed Current Range Test*', 'CRIT1', 42460, 1)
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7091)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7091, 2325, 'OOC-Passed Prior Test Overlaps Alternate Range Failed Test', 'CRIT1', 42461, 1)
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7092)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7092, 2325, 'OOC-Passed Prior Test Overlaps Alternate Range Failed Test*', 'CRIT1', 42462, 1)
SET IDENTITY_INSERT [dbo].[CHECK_CATALOG_RESULT] OFF
PRINT(N'Operation applied to 4 rows out of 4')
COMMIT TRANSACTION
GO

------------------------------------------------------
--	ECMPS_AUX DATA SQL (END)
------------------------------------------------------

------------------------------------------------------
--	ECMPS_AUX VERSION SQL (BEGIN)
------------------------------------------------------

USE ECMPS_AUX
GO

PRINT(N'Add row to [dbo].[ECMPS_VERSION_LOG]')
GO
UPDATE [ECMPS_AUX].[dbo].[ECMPS_VERSION_LOG] SET [IS_CURRENT_FLG]='N' WHERE IsNull([IS_CURRENT_FLG],'X') <> 'N' AND [REVISION] <> '2022 Q2'
IF NOT EXISTS( SELECT [REVISION] FROM [ECMPS_AUX].[dbo].[ECMPS_VERSION_LOG] WHERE [REVISION]='2022 Q2' )
    INSERT INTO [ECMPS_AUX].[dbo].[ECMPS_VERSION_LOG] ([MAJOR], [MINOR], [REVISION], [DESCRIPTION], [EXPECTED_CODE_VERSION], [MP_XSD_VERSION], [QA_XSD_VERSION], [EM_XSD_VERSION], [RELEASE_DATE], [IS_CURRENT_FLG]) 
    VALUES (1, 20222, '2022 Q2', '2022 Q2 Release', '1.20222.0615.*', '1.2', '1.3', '1.7', '2022-06-15 00:00:00.000', 'Y')

PRINT(N'Update [ECMPS_VERSION_LOG] in ECMPS and ECMPS_WS')
GO
DELETE FROM [ECMPS].[Client].[ECMPS_VERSION_LOG]
DELETE FROM [ECMPS_WS].[Client].[ECMPS_VERSION_LOG]

INSERT INTO [ECMPS].[Client].[ECMPS_VERSION_LOG] ([MAJOR], [MINOR], [REVISION], [IS_CURRENT_FLG]) 
	SELECT MAJOR, MINOR, REVISION, IS_CURRENT_FLG
	FROM [ECMPS_AUX].[dbo].[ECMPS_VERSION_LOG] evl
	WHERE NOT EXISTS ( SELECT REVISION FROM [ECMPS].[Client].[ECMPS_VERSION_LOG] WHERE REVISION=evl.REVISION )

INSERT INTO [ECMPS_WS].[Client].[ECMPS_VERSION_LOG] ([MAJOR], [MINOR], [REVISION], [IS_CURRENT_FLG]) 
	SELECT MAJOR, MINOR, REVISION, IS_CURRENT_FLG
	FROM [ECMPS_AUX].[dbo].[ECMPS_VERSION_LOG] evl
	WHERE NOT EXISTS ( SELECT REVISION FROM [ECMPS_WS].[Client].[ECMPS_VERSION_LOG] WHERE REVISION=evl.REVISION )

------------------------------------------------------
--	ECMPS_AUX VERSION SQL (END)
------------------------------------------------------

--
-- Make sure we know it is a shared DB
--
UPDATE ECMPS_AUX..SYSTEM_PARAMETER
SET PARAM_VALUE2='1'
WHERE SYS_PARAM_NAME='DB_SETTINGS'
  AND PARAM_NAME2='IsSharedDB'
  AND PARAM_VALUE2='0'
GO

-- End Message
PRINT 'Update script has ended.'
PRINT 'If you encountered errors, email ECMPS Technical Support at ecmps-support@camdsupport.com'
GO
SET NOEXEC OFF